@@ -11,8 +11,8 @@ from mmdet.apis import inference_detector, init_detector, show_result_pyplot
 class Detector:
     """Instantiate an object detector.
 
-    >>> cfg_options = {"test_pipeline.1": dict(img_scale=(800, 800), scale_factor=None)}
-    >>> cfg_options = {"test_pipeline.1": dict(img_scale=None, scale_factor=1.0)}
+    >>> cfg_options = {"data.test.pipeline.1": dict(img_scale=(800, 800), scale_factor=None)}
+    >>> cfg_options = {"data.test.pipeline.1": dict(img_scale=None, scale_factor=1.0)}
 
     Args:
         config_file (str): Config file path.
@@ -101,13 +101,13 @@ class Detector:
             f.write(text)
 
 
-def func(root, config_file, checkpoint_file, images_dir, score_thr, out_dir, txt_file):
+def func(root, config_file, checkpoint_file, cfg_options, images_dir, score_thr, out_dir, txt_file):
     root = Path(root)
 
     config_file = str(root / config_file)
     checkpoint_file = str(root / checkpoint_file)
 
-    executor = Detector(config_file, checkpoint_file)
+    executor = Detector(config_file, checkpoint_file, cfg_options=cfg_options)
     results = executor.test_images(images_dir, score_thr, out_dir)
 
     if txt_file is not None:
@@ -129,11 +129,13 @@ def parse_args(args=None):
     parser.add_argument("images_dir", type=str,
                         help="a directory of images")
     parser.add_argument("-s", dest="score_thr", type=float, default=0.05,
-                        help="minimum score of bboxes to be shown")
+                        help="minimum score of bboxes to display")
     parser.add_argument("-o", dest="out_dir", type=str, default=None,
                         help="draw boxes on the image")
     parser.add_argument("-f", dest="txt_file", type=str, default="predictions.txt",
                         help="format and save results to a txt file")
+    parser.add_argument("-e", dest="cfg_options", type=str, default=None,
+                        help="to override some settings")
 
     args = parser.parse_args(args=args)
     return vars(args)
@@ -143,6 +145,10 @@ def main(args=None):
     kwargs = parse_args(args)
     print(f"{__file__}: {kwargs}")
 
+    cfg_options = kwargs["cfg_options"]
+    if cfg_options is not None:
+        kwargs["cfg_options"] = eval(cfg_options)
+
     print(func(**kwargs))
 
     return 0
